@@ -1,10 +1,8 @@
-from typing import Optional, Union
 import shutil
-from .text import Text, Token
-
+from tko.util.text import Text
 
 class RawTerminal:
-    __term_width: Optional[int] = None
+    __term_width: None | int = None
 
     def __init__(self):
         pass
@@ -24,9 +22,9 @@ class RawTerminal:
         RawTerminal.__term_width = value
 
     @staticmethod
-    def centralize(text: Text | str, filler: Token | str = Token(" ")):
+    def centralize(text: Text | str, filler: Text.Token | str = Text.Token(" ")):
         if isinstance(filler, str):
-            filler2: Token = Token(filler)
+            filler2: Text.Token = Text.Token(filler)
         else:
             filler2 = filler
 
