@@ -1,11 +1,6 @@
-
-import os
-import re
-import configparser
-
-from typing import List, Optional
+# from typing import override
 import urllib.request
-from tko.util.remote_md import RemoteLink, RemoteCfg, Absolute
+from tko.feno.remote_md import RemoteLink, Absolute
 from tko.util.decoder import Decoder
 
 class RemoteUrl:
@@ -34,12 +29,12 @@ class RemoteUrl:
 
     def download_absolute_to(self, filename: str):
         [tempfile, __content] = urllib.request.urlretrieve(self.get_raw_url(), filename)
-        content = ""
         content = Decoder.load(tempfile)
         if self.remote is not None:
             content = Absolute.relative_to_absolute(content, self.remote)
         Decoder.save(filename, content)
         return
 
+    # @override
     def __str__(self):
         return self.get_raw_url()
